rename gsm_subscriber_connection to ran_conn

In preparation for inter-BSC and inter-MSC handover, we need to separate the
subscriber management logic from the actual RAN connections. What better time
to finally rename gsm_subscriber_connection.

* Name choice:

In 2G, this is a connection to the BSS, but even though 3GPP TS commonly talk
of "BSS-A" and "BSS-B" when explaining handover, it's not good to call it
"bss_conn": in 3G a BSS is called RNS, IIUC.

The overall term for 2G (GERAN) and 3G (UTRAN) is RAN: Radio Access Network.

* Rationale:

A subscriber in the MSC so far has only one RAN connection, but e.g. for
inter-BSC handover, a second one needs to be created to handover to. Most of
the items in the former gsm_subscriber_connection are actually related to the
RAN, with only a few MM and RTP related items. So, as a first step, just rename
it to ran_conn, to cosmetically prepare for moving the not strictly RAN related
items away later.

Also:

- Rename some functions from msc_subscr_conn_* to ran_conn_*
- Rename "Subscr_Conn" FSM instance name to "RAN_conn"
- Rename SUBSCR_CONN_* to RAN_CONN_*

Change-Id: Ic595f7a558d3553c067f77dc67543ab59659707a
diff --git a/include/osmocom/msc/gsm_data.h b/include/osmocom/msc/gsm_data.h
index 864bc0a..12a02bd 100644
--- a/include/osmocom/msc/gsm_data.h
+++ b/include/osmocom/msc/gsm_data.h
@@ -90,11 +90,11 @@
 }
 
 /* active radio connection of a mobile subscriber */
-struct gsm_subscriber_connection {
-	/* global linked list of subscriber_connections */
+struct ran_conn {
+	/* global linked list of ran_conn instances */
 	struct llist_head entry;
 
 	/* FSM instance to control the subscriber connection's permissions and lifetime. */
 	struct osmo_fsm_inst *fi;
 	enum complete_layer3_type complete_layer3_type;
 
@@ -168,12 +168,12 @@
 		struct osmo_sccp_user *scu;
 
 		/* The address of the BSC that is associated
 		 * with this subscriber connection */
 		struct osmo_sccp_addr bsc_addr;
 
 		/* The connection identifier that is used
 		 * to reference the SCCP connection that is
 		 * associated with this subscriber connection */
 		uint32_t conn_id;
 
 		bool waiting_for_clear_complete;
@@ -293,9 +293,9 @@
 	mncc_recv_cb_t mncc_recv;
 	struct llist_head upqueue;
 	/*
 	 * TODO: Move the trans_list into the subscriber connection and
 	 * create a pending list for MT transactions. These exist before
 	 * we have a subscriber connection.
 	 */
 	struct llist_head trans_list;
 
@@ -311,8 +311,8 @@
 	/* control interface */
 	struct ctrl_handle *ctrl;
 
-	/* all active subscriber connections. */
-	struct llist_head subscr_conns;
+	/* all active RAN connections. */
+	struct llist_head ran_conns;
 
 	/* if override is nonzero, this timezone data is used for all MM
 	 * contexts. */
@@ -90,11 +90,11 @@
 	struct llist_head entry;
 
-	/* FSM instance to control the subscriber connection's permissions and lifetime. */
+	/* FSM instance to control the RAN connection's permissions and lifetime. */
 	struct osmo_fsm_inst *fi;
 	enum complete_layer3_type complete_layer3_type;
@@ -168,12 +168,12 @@
 
 		/* The address of the BSC that is associated
-		 * with this subscriber connection */
+		 * with this RAN connection */
 		struct osmo_sccp_addr bsc_addr;
 
@@ -168,12 +168,12 @@
 		/* The connection identifier that is used
 		 * to reference the SCCP connection that is
-		 * associated with this subscriber connection */
+		 * associated with this RAN connection */
 		uint32_t conn_id;
 
@@ -293,9 +293,9 @@
 	struct llist_head upqueue;
 	/*
-	 * TODO: Move the trans_list into the subscriber connection and
+	 * TODO: Move the trans_list into the RAN connection and
 	 * create a pending list for MT transactions. These exist before
@@ -293,9 +293,9 @@
 	 * create a pending list for MT transactions. These exist before
-	 * we have a subscriber connection.
+	 * we have a RAN connection.
 	 */
 	struct llist_head trans_list;